==> senior_design_system-0.21.4.tar.gz: example/lib/pages/expansion_panel.example.dart <==
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/panel.dart';
import '../widgets/page_wrapper.dart';

class ExpansionPanelExample extends StatefulWidget {
  final List<dynamic> infoOne = [
    {
      'evaluation': 5,
      'user': 'Maria Aparecida da Silva',
      'note':
          'O sistema é muito responsivo e a sua interface é muito bonita e intuitiva. Uso todos os dias nas minhas atividades diárias.',
      'is_expanded': false,
    },
    {
      'evaluation': 2,
      'user': 'Francisco Golçalves Filho',
      'note': 'Tenho muitos travamentos e não atende às minhas necessidades. Por favor ajustem isso.',
      'is_expanded': false,
    },
  ];

  final List<dynamic> infoTwo = [
    {
      'title': 'Material de Escritório',
      'requester': 'Maria Aparecida da Silva',
      'cost': 300300300.00,
      'is_checked': false,
      'is_expanded': false,
    },
    {
      'title': 'Matéria-prima',
      'requester': 'Francisco Gonçalves Filho',
      'cost': 300300300.00,
      'is_checked': false,
      'is_expanded': false,
    },
  ];

  ExpansionPanelExample({Key? key}) : super(key: key);

  @override
  _ExpansionPanelExampleState createState() => _ExpansionPanelExampleState();
}

Widget buildStars(int value) {
  List<Widget> stars = [];

  for (int i = 0; i < value; i++) {
    stars.add(
      Icon(
        FontAwesomeIcons.star,
        size: SeniorTypographyIconSize.body,
      ),
    );
  }

  return Row(
    children: stars,
  );
}

class _ExpansionPanelExampleState extends State<ExpansionPanelExample> {
  Widget buildPanelOne() {
    return SeniorExpansionPanelList(
      list: widget.infoOne
          .map(
            (e) => SeniorPanelData(
              headerInfo: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Text(e['user']),
                  buildStars(e['evaluation']),
                ],
              ),
              expandedInfo: Text(e['note']),
              severityColor: e['evaluation'] >= 3 ? SeniorColors.manchesterColorGreen : SeniorColors.manchesterColorRed,
              isExpanded: e['is_expanded'],
            ),
          )
          .toList(),
      expansionCallback: (index, value) {
        setState(() {
          widget.infoOne[index]['is_expanded'] = !value;
        });
      },
    );
  }

  Widget buildPanelTwo() {
    List<dynamic> info = widget.infoTwo;

    return SeniorExpansionPanelList(
      list: info
          .map(
            (e) => SeniorPanelData(
              headerInfo: SeniorCheckbox(
                title: e['title'],
                value: e['is_checked'],
                onChanged: (value) {
                  if (value == null) return;
                  setState(() {
                    e['is_checked'] = value;
                  });
                },
              ),
              expandedInfo: Column(
                crossAxisAlignment: CrossAxisAlignment.stretch,
                children: [
                  Container(
                    child: Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        Text(
                          'Solicitante',
                          style: SeniorTypography.small(
                            color: SeniorColors.neutralColor600,
                          ),
                        ),
                        Text(
                          e['requester'],
                          style: SeniorTypography.body(
                            color: SeniorColors.neutralColor800,
                          ),
                        ),
                      ],
                    ),
                  ),
                  Container(
                    child: Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        Text(
                          'Custo',
                          style: SeniorTypography.small(
                            color: SeniorColors.neutralColor600,
                          ),
                        ),
                        Text(
                          'R\$ ${e['cost']}',
                          style: SeniorTypography.body(
                            color: SeniorColors.neutralColor800,
                          ),
                        ),
                      ],
                    ),
                  ),
                ],
              ),
              actions: [
                SeniorButton(
                  label: 'Negar',
                  size: SeniorButtonSize.big,
                  type: SeniorButtonType.secondary,
                  onPressed: () {},
                ),
                SeniorButton(
                  label: 'Aprovar',
                  size: SeniorButtonSize.big,
                  onPressed: () {},
                ),
              ],
              isExpanded: e['is_expanded'],
            ),
          )
          .toList(),
      expansionCallback: (index, value) {
        setState(() {
          info[index]['is_expanded'] = !value;
        });
      },
    );
  }

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Expansion Panel',
      child: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.all(16.0),
          child: Column(
            children: [
              Panel(
                title: 'Título e ícones',
                child: buildPanelOne(),
              ),
              Panel(
                title: 'Checkbox',
                child: buildPanelTwo(),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

==> senior_design_system-0.26.2.tar.gz: example/lib/pages/expansion_panel.example.dart <==
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/panel.dart';
import '../widgets/page_wrapper.dart';

class ExpansionPanelExample extends StatefulWidget {
  final List<dynamic> infoOne = [
    {
      'evaluation': 5,
      'user': 'Maria Aparecida da Silva',
      'note':
          'O sistema é muito responsivo e a sua interface é muito bonita e intuitiva. Uso todos os dias nas minhas atividades diárias.',
      'is_expanded': false,
    },
    {
      'evaluation': 2,
      'user': 'Francisco Golçalves Filho',
      'note':
          'Tenho muitos travamentos e não atende às minhas necessidades. Por favor ajustem isso.',
      'is_expanded': false,
    },
  ];

  final List<dynamic> infoTwo = [
    {
      'title': 'Material de Escritório',
      'requester': 'Maria Aparecida da Silva',
      'cost': 300300300.00,
      'is_checked': false,
      'is_expanded': false,
    },
    {
      'title': 'Matéria-prima',
      'requester': 'Francisco Gonçalves Filho',
      'cost': 300300300.00,
      'is_checked': false,
      'is_expanded': false,
    },
  ];

  ExpansionPanelExample({Key? key}) : super(key: key);

  @override
  _ExpansionPanelExampleState createState() => _ExpansionPanelExampleState();
}

Widget buildStars(int value) {
  final List<Widget> stars = [];

  for (int i = 0; i < value; i++) {
    stars.add(
      const Icon(
        FontAwesomeIcons.star,
        size: SeniorTypographyIconSize.body,
      ),
    );
  }

  return Row(
    children: stars,
  );
}

class _ExpansionPanelExampleState extends State<ExpansionPanelExample> {
  Widget buildPanelOne() {
    return SeniorExpansionPanelList(
      list: widget.infoOne
          .map(
            (e) => SeniorPanelData(
              headerInfo: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Text(e['user']),
                  buildStars(e['evaluation']),
                ],
              ),
              expandedInfo: Text(e['note']),
              severityColor: e['evaluation'] >= 3
                  ? SeniorColors.manchesterColorGreen
                  : SeniorColors.manchesterColorRed,
              isExpanded: e['is_expanded'],
            ),
          )
          .toList(),
      expansionCallback: (index, value) {
        setState(() {
          widget.infoOne[index]['is_expanded'] = !value;
        });
      },
    );
  }

  Widget buildPanelTwo() {
    final List<dynamic> info = widget.infoTwo;

    return SeniorExpansionPanelList(
      list: info
          .map(
            (e) => SeniorPanelData(
              headerInfo: SeniorCheckbox(
                title: e['title'],
                value: e['is_checked'],
                onChanged: (value) {
                  if (value == null) {
                    return;
                  }
                  setState(() {
                    e['is_checked'] = value;
                  });
                },
              ),
              expandedInfo: Column(
                crossAxisAlignment: CrossAxisAlignment.stretch,
                children: [
                  Container(
                    child: Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        Text(
                          'Solicitante',
                          style: SeniorTypography.small(
                            color: SeniorColors.neutralColor600,
                          ),
                        ),
                        Text(
                          e['requester'],
                          style: SeniorTypography.body(
                            color: SeniorColors.neutralColor800,
                          ),
                        ),
                      ],
                    ),
                  ),
                  Container(
                    child: Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        Text(
                          'Custo',
                          style: SeniorTypography.small(
                            color: SeniorColors.neutralColor600,
                          ),
                        ),
                        Text(
                          'R\$ ${e['cost']}',
                          style: SeniorTypography.body(
                            color: SeniorColors.neutralColor800,
                          ),
                        ),
                      ],
                    ),
                  ),
                ],
              ),
              actions: [
                SeniorButton(
                  label: 'Negar',
                  size: SeniorButtonSize.big,
                  type: SeniorButtonType.secondary,
                  onPressed: () {},
                ),
                SeniorButton(
                  label: 'Aprovar',
                  size: SeniorButtonSize.big,
                  onPressed: () {},
                ),
              ],
              isExpanded: e['is_expanded'],
            ),
          )
          .toList(),
      expansionCallback: (index, value) {
        setState(() {
          info[index]['is_expanded'] = !value;
        });
      },
    );
  }

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Expansion Panel',
      child: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.all(16.0),
          child: Column(
            children: [
              Panel(
                title: 'Título e ícones',
                child: buildPanelOne(),
              ),
              Panel(
                title: 'Checkbox',
                child: buildPanelTwo(),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
